
:orphan:

.. _sphx_glr_source_auto_examples_sg_execution_times:

Computation times
=================
**00:00.859** total execution time for **source_auto_examples** files:

- **00:00.859**: :ref:`sphx_glr_source_auto_examples_plot_contour.py` (``plot_contour.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_ceil_example.py` (``ceil_example.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_get_stability_indices_example.py` (``get_stability_indices_example.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_multidata_example.py` (``multidata_example.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_plot_rh_timeseries.py` (``plot_rh_timeseries.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_plot_sonde.py` (``plot_sonde.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_plot_wind_rose.py` (``plot_wind_rose.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_qc_example.py` (``qc_example.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_skewt_example.py` (``skewt_example.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_twod_example.py` (``twod_example.py``)
- **00:00.000**: :ref:`sphx_glr_source_auto_examples_weighted_average_example.py` (``weighted_average_example.py``)
